package com.ces.common.device.service;

import cn.hutool.http.HttpUtil;
import com.alibaba.fastjson2.JSONObject;
import com.ces.common.device.dto.DeviceDTO;
import com.ces.common.device.dto.DeviceGroupDTO;
import com.ces.common.device.support.QueryWrapper;
import com.ces.common.utils.ObjectUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 设备查询服务
 *
 * @author Tao
 */

@Service
public class DeviceQueryService {

    @Value("${monitor.query-service.api}")
    private String baseApi;

    private final String SUCCESS_CODE = "0";

    private static final Logger logger = LoggerFactory.getLogger(DeviceQueryService.class);

    /**
     * 获取设备分组tree
     *
     * @return
     */
    public List<DeviceGroupDTO> getDeviceGroupTree() {

        return getDeviceGroupTree(null);

    }

    /**
     * 获取设备分组tree
     *
     * @param name 分组名称
     * @return
     */
    public List<DeviceGroupDTO> getDeviceGroupTree(String name) {
        try {

            Map<String, Object> params = new HashMap<>(1);

            if (ObjectUtils.isNotBlank(name)) {
                params.put("name", name);
            }

            String result = HttpUtil.get(baseApi + "/group/tree", params);
            JSONObject resultObj = JSONObject.parseObject(result);

            String code = resultObj.getString("code");
            Object dataList = resultObj.get("result");

            if (!SUCCESS_CODE.equals(code)) {
                logger.error("调用 获取设备分组列表 接口失败！");
                return null;
            }

            if (dataList == null) {
                logger.error("未获取到设备分组列表！");
                return null;
            }

            return com.alibaba.fastjson.JSONObject.parseArray(JSONObject.toJSONString(dataList), DeviceGroupDTO.class);

        } catch (Exception e) {
            logger.error("调用 获取设备分组列表 接口失败！");
            return null;
        }
    }

    /**
     * 根据分组ID获取设备列表
     *
     * @param groupId 分组id
     * @return
     */
    public String getDevicesByGroupId(String groupId) {

        try {
            Map<String, String> params = new HashMap<>(1);

            if (ObjectUtils.isBlank(groupId)) {
                logger.error("分组ID不能为空...");

                return null;
            }

            params.put("groupId", groupId);

            return HttpUtil.post(baseApi + "/group/device-list", JSONObject.toJSONString(params));

        } catch (Exception e) {
            logger.error("调用 获取分组下设备列表 接口失败！");
            return null;
        }
    }

    public List<DeviceDTO> getDeviceByExt(QueryWrapper queryWrapper) {

        try {
            Map<String, Object> paramMap = queryWrapper.getParamMap();

            String result = HttpUtil.get(baseApi + "/ext", paramMap);
            JSONObject resultObj = JSONObject.parseObject(result);

            String code = resultObj.getString("code");
            JSONObject dataObj = resultObj.getJSONObject("result");

            if (!SUCCESS_CODE.equals(code)) {
                logger.error("调用 设备查询 接口失败！");
                return null;
            }

            if (dataObj == null) {
                logger.error("未获取到设备列表！");
                return null;
            }

            Object dataList = dataObj.get("data");

            if (dataList == null) {
                logger.error("未获取到设备列表！");
                return null;
            }

            return com.alibaba.fastjson.JSONObject.parseArray(JSONObject.toJSONString(dataList), DeviceDTO.class);
        } catch (Exception e) {
            logger.error("接口调用失败...", e);
            return null;
        }
    }

    public DeviceDTO getDeviceById(String deviceId) {

        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("id", deviceId);

        List<DeviceDTO> dtoList = this.getDeviceByExt(queryWrapper);

        if (dtoList == null || dtoList.isEmpty()) {
            return null;
        }
        return dtoList.get(0);
    }
}
