package com.ces.common.device.support;

import com.ces.common.utils.ObjectUtils;

import java.util.HashMap;
import java.util.Map;

/**
 * @author Tao
 */
public class QueryWrapper {

    public static final class OPTION_KEY {

        public static final String EQ = "eq";

        public static final String NOT_EQ = "not";

        public static final String LIKE = "like";

        public static final String NOT_LIKE = "nlike";

        public static final String CONTAINS = "contains";
    }

    private final Map<String, Map<String, String>> params;

    public QueryWrapper() {
        params = new HashMap<>(16);
    }

    public synchronized void eq(String key, String val){
        this.addParams(OPTION_KEY.EQ, key, val);
    }

    public synchronized void notEq(String key, String val) {
        this.addParams(OPTION_KEY.NOT_EQ, key, val);
    }

    public synchronized void like(String key, String val) {
        this.addParams(OPTION_KEY.LIKE, key, val);
    }

    public synchronized void notLike(String key, String val) {
        this.addParams(OPTION_KEY.NOT_LIKE, key, val);
    }

    public synchronized void contains(String key, String val) {
        this.addParams(OPTION_KEY.CONTAINS, key, val);
    }

    public void addParams(String op, String key, String val) {
        if (ObjectUtils.isBlank(key) || ObjectUtils.isBlank(val)) {
            return;
        }

        Map<String, String> eqParams = params.get(op);

        if (ObjectUtils.isEmpty(eqParams)) {
            eqParams = new HashMap<>(16);
            params.put(op, eqParams);
        }

        eqParams.put(key, val);
    }

    public Map<String, Object> getParamMap() {

        Map<String, Object> paramMap = new HashMap<>(16);

        for (String opKey : this.params.keySet()) {

            Map<String, String> kvMap = this.params.get(opKey);
            if (ObjectUtils.isEmpty(kvMap)) {
                continue;
            }

            for (String key : kvMap.keySet()) {
                paramMap.put("f_" + opKey + "_" + key, kvMap.get(key));
            }

        }

        if (ObjectUtils.isEmpty(paramMap)) {
            return null;
        }

        return paramMap;
    }
}
