package com.ces.framework.authsystem;

import com.ces.common.utils.ObjectUtils;
import com.cesgroup.authen4.ws.CoreHttpClientWS;
import com.cesgroup.authen4.ws.entity.Role;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import javax.annotation.PostConstruct;
import java.util.ArrayList;
import java.util.List;

/**
 * @author Tao
 * @date 2023/11/20
 */
@Component
public class AuthSystemUtils {

    private static String host;

    private static String tenantId;

    private static CoreHttpClientWS coreHttpClientWS;

    @Value("${monitor.authsystem.host}")
    public void setHost(String host) {
        AuthSystemUtils.host = host;
    }

    @Value("${monitor.authsystem.tenantId}")
    public void setTenantId(String tenantId) {
        AuthSystemUtils.tenantId = tenantId;
    }

    @PostConstruct
    public void init() {
        coreHttpClientWS = CoreHttpClientWS.getCoreHttpClientWS(host);
    }

    /**
     * 通过用户id，获取用户角色Code
     *
     * @param userId
     *            用户id
     * @return
     */
    public static List<String> getUserRoleCodeList(String userId) {

        // 查询用户角色
        List<Role> roleList = coreHttpClientWS.queryAllRoleByUserId(userId);
        List<String> resultList = null;
        if (ObjectUtils.isNotEmpty(roleList)) {
            resultList = new ArrayList<>();
            for (Role role : roleList) {
                resultList.add(role.getCode());
            }
        }
        return resultList;
    }

    public static CoreHttpClientWS getCoreHttpClientWS() {
        return coreHttpClientWS;
    }

    public static String getTenantId() {
        return tenantId;
    }
}
