package com.ces.framework.shiro.realm;

import com.ces.common.utils.ObjectUtils;
import com.ces.framework.shiro.dto.UserDTO;
import com.ces.framework.shiro.token.UserToken;
import com.ces.web.login.service.LoginService;
import org.apache.shiro.authc.AuthenticationException;
import org.apache.shiro.authc.AuthenticationInfo;
import org.apache.shiro.authc.AuthenticationToken;
import org.apache.shiro.authc.SimpleAuthenticationInfo;
import org.apache.shiro.authz.AuthorizationInfo;
import org.apache.shiro.authz.SimpleAuthorizationInfo;
import org.apache.shiro.realm.AuthorizingRealm;
import org.apache.shiro.subject.PrincipalCollection;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;

/**
 * @author Tao
 * @date 2023/11/20
 */
public class UserRealm extends AuthorizingRealm {

    @Autowired
    private LoginService loginService;

    /**
     * 登录验证
     */
    @Override
    protected AuthenticationInfo doGetAuthenticationInfo(AuthenticationToken token)
            throws AuthenticationException {

        UserToken userToken = (UserToken)token;

        String loginName = userToken.getUsername();
        String password = new String(userToken.getPassword());
        String tenantId = userToken.getTenantId();

        UserDTO userDTO = null;
        try {

            userDTO = loginService.login(loginName, password, tenantId);

        } catch (Exception e) {
            throw new AuthenticationException(e.getMessage(), e);
        }

        return new SimpleAuthenticationInfo(userDTO, password, getName());
    }

    /**
     * 授权操作
     */
    @Override
    protected AuthorizationInfo doGetAuthorizationInfo(PrincipalCollection principals) {

        SimpleAuthorizationInfo simpleAuthorizationInfo = new SimpleAuthorizationInfo();

        UserDTO userDTO = (UserDTO) principals.getPrimaryPrincipal();

        List<String> roleCodeList = userDTO.getRoleCodeList();

        if (ObjectUtils.isNotEmpty(roleCodeList)) {
            simpleAuthorizationInfo.addRoles(roleCodeList);
        }

        return simpleAuthorizationInfo;
    }

}
