package com.ces.web.device.controller;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ces.common.core.domain.Result;
import com.ces.common.device.dto.DeviceDTO;
import com.ces.common.device.service.DeviceQueryService;
import com.ces.common.device.support.QueryWrapper;
import com.ces.common.utils.ObjectUtils;
import com.ces.web.device.entity.DeviceInfo;
import com.ces.web.device.service.IDeviceService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.servlet.ModelAndView;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author Tao
 */
@RestController
@RequestMapping("/device")
public class DeviceController {

    @Autowired
    private IDeviceService deviceService;

    @Autowired
    private DeviceQueryService deviceQueryService;

    /**
     * 获取所有监狱信息
     */
    @GetMapping("/getAllPrison")
    public Result getAllPrison() {

        return Result.success(deviceService.getPrisonList());
    }


    /**
     * 根据监狱名称获取所有大楼信息
     * @param prisonName 监狱名称
     */
    @GetMapping("/getBuildInfoByPrison")
    public Result getBuildInfoByPrison(String prisonName) {

        return Result.success(deviceService.getBuildList(prisonName));
    }

    /**
     * 获取所有楼层信息
     * @param prisonName 监狱名称
     * @param buildName 大楼名称
     */
    @GetMapping("/getFloorInfoByBuildName")
    public Result getFloorInfoByBuildName(String prisonName, String buildName) {

        return Result.success(deviceService.getFloorList(prisonName, buildName));
    }

    /**
     * 根据gbid获取设备信息
     * @param gbId gbId
     * @return
     */
    @GetMapping("getDeviceByGbId")
    public Result getDeviceByGbId(String gbId) {
        LambdaQueryWrapper<DeviceInfo> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(DeviceInfo::getGbId, gbId);
        DeviceInfo deviceInfo = deviceService.getOne(queryWrapper);
        return Result.success(deviceInfo);
    }

    /**
     * 根据gbid获取同房间所有设备信息
     * @param gbId gbId
     * @return
     */
    @GetMapping("/getDeviceListByGbId")
    public Result getDeviceListByGbId(String gbId) {

        return deviceService.getDeviceListByGbId(gbId);
    }

    /**
     * 获取设备列表的状态
     */
    @GetMapping("/getListStatus")
    public Result getListStatus(String gbIds) {

        if (ObjectUtils.isBlank(gbIds)) {
            return Result.success();
        }

        String[] gbIdArray = gbIds.split(",");

        Map<String, String> resultMap = new HashMap<>(gbIdArray.length);

        for (String gbId : gbIdArray) {
            QueryWrapper queryWrapper = new QueryWrapper();
            queryWrapper.eq("gbid", gbId);
            List<DeviceDTO> deviceByExt = deviceQueryService.getDeviceByExt(queryWrapper);
            if (ObjectUtils.isNotEmpty(deviceByExt)) {
                DeviceDTO device = deviceByExt.get(0);
                resultMap.put(device.getGbid(), device.getStatus());
            }
        }

        return Result.success(resultMap);
    }
}
