package com.ces.web.device.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ces.common.core.domain.Result;
import com.ces.web.device.entity.DeviceInfo;
import com.ces.web.device.mapper.DeviceMapper;
import com.ces.web.device.service.IDeviceService;
import org.springframework.stereotype.Service;
import java.util.List;
import java.util.Map;

/**
 * @author Tao
 */
@Service
public class DeviceServiceImpl extends ServiceImpl<DeviceMapper, DeviceInfo> implements IDeviceService {

    /**
     * 获取所有监狱名称
     */
    @Override
    public List<String> getPrisonList() {
        return getBaseMapper().getPrisonNameList();
    }

    /**
     * 根据监狱名称获取所有大楼信息
     * @param prisonName 监狱名称
     */
    @Override
    public List<Map<String, Object>> getBuildList(String prisonName) {
        return getBaseMapper().getBuildNameList(prisonName);
    }

    /**
     * 获取楼层信息
     * @param prisonName 监狱名称
     * @param buildName 大楼名称
     */
    @Override
    public List<String> getFloorList(String prisonName, String buildName) {
        return getBaseMapper().getFloorNameList(prisonName, buildName);
    }

    /**
     * 统计每个楼层摄像头个数
     * @param prisonName 监狱名称
     * @param buildName 楼名/监区名
     * @return
     */
    @Override
    public List<Map<String, Object>> getCntByPrisonNameAndBuildName(String prisonName, String buildName) {
        return getBaseMapper().getCntByPrisonNameAndBuildName(prisonName,buildName);
    }

    /**
     * 获取设备信息
     * @param prisonName 监狱名称
     * @param buildName 楼名/监区名
     * @param floor 楼层
     * @return
     */
    @Override
    public List<String> getGbidByPrisonNameAndBuildNameAndFloor(String prisonName, String buildName, String floor) {
        return getBaseMapper().getGbidByPrisonNameAndBuildNameAndFloor(prisonName,buildName,floor);
    }

    @Override
    public Result getDeviceListByGbId(String gbId) {
        LambdaQueryWrapper<DeviceInfo> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(DeviceInfo::getGbId, gbId);
        DeviceInfo deviceInfo = getBaseMapper().selectOne(queryWrapper);

        if (deviceInfo == null) {
            return Result.error("未查询到此设备信息！");
        }

        List<DeviceInfo> deviceInfoList = getBaseMapper().getDeviceListByDevice(deviceInfo);

        return Result.success(deviceInfoList);
    }

    /**
     * 获取楼层信息
     * @param prisonName
     * @param areaName
     * @return
     */
    @Override
    public List<String> findByPrisonNameAndAreaName(String prisonName, String areaName) {
       return getBaseMapper().findByPrisonNameAndAreaName(prisonName,areaName);
    }

    /**
     * 根据楼层统计监控点
     * @param prisonName
     * @param buildName
     * @return
     */
    @Override
    public List<Map<String, String>> countByPrisonNameAndBuildName(String prisonName, String buildName) {
        return getBaseMapper().countByPrisonNameAndBuildName(prisonName,buildName);
    }

    /**
     * 根据楼层统计监控点
     * @param prisonName
     * @param areaName
     * @return
     */
    @Override
    public List<Map<String, String>> countByPrisonNameAndAreaName(String prisonName, String areaName) {
        return getBaseMapper().countByPrisonNameAndAreaName(prisonName,areaName);
    }

    @Override
    public List<DeviceInfo> findByPrisonAndAreaAndFloor(String prisonName, String areaName, String floorName) {
        return getBaseMapper().findByPrisonAndAreaAndFloor(prisonName,areaName,floorName);
    }

    @Override
    public List<DeviceInfo> findByPrisonAndBuildAndFloor(String prisonName, String buildName, String floorName) {
        return getBaseMapper().findByPrisonAndBuildAndFloor(prisonName,buildName,floorName);
    }
}
