package com.ces.web.login.controller;

import cn.hutool.core.util.StrUtil;
import com.ces.common.core.domain.Result;
import com.ces.common.utils.ObjectUtils;
import com.ces.framework.authsystem.AuthSystemUtils;
import com.ces.framework.shiro.token.UserToken;
import org.apache.shiro.SecurityUtils;
import org.apache.shiro.authc.IncorrectCredentialsException;
import org.apache.shiro.subject.Subject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

/**
 * @author Tao
 * @date 2023/11/20
 */
@Controller
public class LoginController {

    @GetMapping("/login")
    public ModelAndView loginView() {
        Subject subject = SecurityUtils.getSubject();
        if (subject.isAuthenticated()) {
            subject.logout();
        }
        // 没有登陆权限
        return new ModelAndView("login");
    }

    @PostMapping("/login")
    @ResponseBody
    public Result login(String loginName, String password) {
        Subject subject = SecurityUtils.getSubject();

        if (ObjectUtils.isNotBlank(loginName) && ObjectUtils.isNotBlank(password)) {

            try {

                subject.login(new UserToken(loginName, password, AuthSystemUtils.getTenantId()));

                return Result.success();
            } catch (IncorrectCredentialsException e) {
                return Result.error("账号或密码错误！");
            } catch (Exception e) {
                e.printStackTrace();
                String msg = e.getMessage();
                if (StrUtil.isBlank(msg)) {
                    msg = "服务器错误，登录失败！";
                }
                return Result.error(msg);
            }

        }
        return Result.error("账号或密码不能为空！");
    }
}
