package com.ces.web.qp.controller;

import com.ces.common.constant.Constant;
import com.ces.common.core.domain.Result;
import com.ces.web.device.entity.DeviceInfo;
import com.ces.web.device.service.IDeviceService;
import org.apache.shiro.authz.annotation.RequiresRoles;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 王少强
 */
@Controller
@RequestMapping("/qp")
public class QPController {

    @Autowired
    private IDeviceService deviceService;

    private Logger logger = LoggerFactory.getLogger(QPController.class);


    /**
     * 进入青浦首页
     * @return
     */
    @GetMapping
    @RequiresRoles({Constant.RoleCode.QP})
    public ModelAndView qpIndex(){
        return new ModelAndView("qp/areaPlan");
    }

    /**
     * 根据楼名统计监控数
     * @return
     */
    @GetMapping("/build/monitors/count")
    @RequiresRoles({Constant.RoleCode.QP})
    public Result countMonitorsByBuild(){

        return Result.success(null);
    }

    /**
     * 进入青浦楼层页面
     * @param area
     * @return
     */
    @GetMapping("/floor")
    @RequiresRoles({Constant.RoleCode.QP})
    public ModelAndView getFloors(String area){
        ModelAndView mv = new ModelAndView("qp/floor");
        List<String> floorList = new ArrayList<String>();
        if(area.contains("监区")){
            floorList = deviceService.findByPrisonNameAndAreaName("沪-青",area);
        }else{
            floorList = deviceService.getFloorList("沪-青",area);
        }
        mv.addObject("area",area);
        mv.addObject("floorList",floorList);
        return mv;
    }

    /**
     * 根据楼层统计监控数
     * @return
     */
    @GetMapping("/floor/monitors/count")
    @RequiresRoles({Constant.RoleCode.QP})
    @ResponseBody
    public Result countMonitorsByFloor(String area){
        List<Map<String,String>> countList = new ArrayList<>();
        if(area.contains("监区")){
            countList = deviceService.countByPrisonNameAndAreaName("沪-青",area);
        }else{
            countList = deviceService.countByPrisonNameAndBuildName("沪-青",area);
        }
        return Result.success(countList);
    }
    @GetMapping("/floor/monitors/list")
    @RequiresRoles({Constant.RoleCode.QP})
    @ResponseBody
    public Result getCameraGbIds(String area,String floor){
        List<DeviceInfo> deviceInfoList = new ArrayList<DeviceInfo>();
        if(area.contains("监区")){
            deviceInfoList = deviceService.findByPrisonAndAreaAndFloor("沪-青",area,floor);
        }else{
            deviceInfoList = deviceService.findByPrisonAndBuildAndFloor("沪-青",area,floor);
        }
        return Result.success(deviceInfoList);
    }
}
