package com.ces.web.xinshoufan.controller;

import com.ces.common.constant.Constant;
import com.ces.common.core.domain.Result;
import com.ces.web.device.entity.DeviceInfo;
import com.ces.web.device.service.IDeviceService;
import org.apache.shiro.authz.annotation.RequiresRoles;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.servlet.ModelAndView;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

@Controller
@RequestMapping("/xinshoufan")
public class XinshoufanController {
    @Autowired
    private IDeviceService deviceService;

    private Logger logger = LoggerFactory.getLogger(XinshoufanController.class);

    /**
     * 进入新收犯首页
     * @return
     */
    @GetMapping
    @RequiresRoles({Constant.RoleCode.XSF})
    public ModelAndView xinshoufanIndex(){
        return new ModelAndView("xinshoufan/areaPlan");
    }

    /**
     * 进入新收犯楼层页面
     * @param area
     * @return
     */
    @GetMapping("/floor")
    @RequiresRoles({Constant.RoleCode.XSF})
    public ModelAndView getFloors(String area){
        ModelAndView mv = new ModelAndView("xinshoufan/floor");
        List<String> floorList = new ArrayList<String>();
        if(area.contains("监区")){
            floorList = deviceService.findByPrisonNameAndAreaName("沪-新",area);
        }else{
            floorList = deviceService.getFloorList("沪-新",area);
        }
        mv.addObject("area",area);
        mv.addObject("floorList",floorList);
        return mv;
    }

    /**
     * 根据楼层统计监控数
     * @return
     */
    @GetMapping("/floor/monitors/count")
    @RequiresRoles({Constant.RoleCode.XSF})
    @ResponseBody
    public Result countMonitorsByFloor(String area){
        List<Map<String,String>> countList = new ArrayList<Map<String,String>>();
        if(area.contains("监区")){
            countList = deviceService.countByPrisonNameAndAreaName("沪-新",area);
        }else{
            countList = deviceService.countByPrisonNameAndBuildName("沪-新",area);
        }
        return Result.success(countList);
    }

    @GetMapping("/floor/monitors/list")
    @RequiresRoles({Constant.RoleCode.XSF})
    @ResponseBody
    public Result getCameraGbIds(String area,String floor){
        List<DeviceInfo> deviceInfoList = new ArrayList<DeviceInfo>();
        if(area.contains("监区")){
            deviceInfoList = deviceService.findByPrisonAndAreaAndFloor("沪-新",area,floor);
        }else{
            deviceInfoList = deviceService.findByPrisonAndBuildAndFloor("沪-新",area,floor);
        }
        return Result.success(deviceInfoList);
    }
}
